from CreateAPI.CreateAPI.functions.CreateAPI import *


RandomJoke(place="/jokes/random")

RandomName(place="/names/random")

OwnPage(place="/orenAPI/aboutME/",name="myname",what_to_show="oren",name2="myname1",what_to_show2="oren1",)
OwnPage1(place="/orenAPI/aboutME/gfh",name="1",what_to_show="oren",name2="myname1",what_to_show2="oren1",)


CreateAPI("localhost","9896",False)